/* -*- mode: c++; c-basic-offset: 3; -*- */
#ifndef GATING_MONITOR_HH
#define GATING_MONITOR_HH

#include "DatEnv.hh"
#include "gatemon_utils.hh"
#include "OperStateCondList.hh"
#include "Trend.hh"
#include "TrigClient.hh"

class DaccAPI;
class GDSPlot;

/**  The gating monitor class tracks the deadtime imposed by the gates
  *  being watched. It optionally plots a log-log histogram of the gating
  *  discriminant value for use in finding pathological epochs or tuning 
  *  the gate threshold value.
  *  \version August 23, 2022
  *  \author John Zweizig <john.zweizig@ligo.org>
  */
class gating_monitor : public DatEnv {
public:
   gating_monitor(int argc,const char* argv[]);
   ~gating_monitor(void);
   void ProcessData(void);
   bool configure(const std::string& file);
   void put_html(void) const;
   void reset(void);

private:
   std::string         _ifo;
   std::string         _osc_file;
   std::string         _osc_cond;
   std::string         _monitor_pfx;
   std::string         _trend_name;
   std::string         _trend_file;
   timeline            _ready_times;
   Interval            _stride;
   std::vector<double> _test_intervals;
   gate_cond_vect      _gates;
   segment_def_vect    _segments;
   trend_def_vect      _trends;
   OperStateCondList   _osc_list;
   TrigClient          _trig_client;
   trig::SegAccountant _seg_acct;
   Trend               _trender;
   Time                _start;
   Time                _current;
};

//======================================  Inline methods.

#endif  // !defined(GATING_MONITOR_HH)
